/****************************************************************
 * File: SendMailWidget.h
 * Authors: Jake Becker   (jabecker@stanford.edu)
 *          Keith Schwarz (htiek@cs.stanford.edu)
 *
 * A header file defining the main window for the email program.
 * You should not need to modify or use the contents of this file.
 */

#include <QtGui>
#include "AddressBookDialog.h"
#include "EmailMessage.h"
#include "ui_email.h"
using namespace std;

class SendMailWidget : public QWidget
{
	/* This next line is a hint to Qt that this is a window object.
	 * This is not standard C++, so don't be scared if you don't
	 * recognize this.
	 */
	Q_OBJECT

	public:
		SendMailWidget();

	/* One of the major drawbacks of the Qt library is that it
	 * abuses the preprocessor to introduce new syntactic constructs.
	 * The term "private slots" is not standard C++, but is rather a
	 * cue to the Qt meta-object compiler that these member functions
	 * are somehow special.  Do not use the keyword slots in your
	 * C++ programs; you'll get a compiler error!
	 */
	private slots:
		void addAttachment();
		void manageAddresses();
		void clearAttachments();
		void sendMessage();
		void resetRecipients();
		void addToRecipient();
		void addCcRecipient();
		void addBccRecipient();
		void removeRecipient();

	private:
		Ui::SendMailWidget 	ui;
		AddressBookDialog 	addressBookDialog;
		QStringList 		addressList;
		QStringListModel 	addressListModel;
		QStringList 		remainingAddressesList;

		void addRecipient(EmailMessage::RecipientType type);
		bool isValidInfo();
		void readAddressBookIntoStringList(QStringList &addressList);
		void reset();
};


