/***************************************************************
 * mail.h
 * Author: Keith Schwarz (htiek@cs.stanford.edu)
 *
 * This header file contains prototypes of the functions you will
 * need to write in order to complete the assignment.  You should
 * not need to modify the contents of this file, and if you do you
 * are probably going to break some of the existing code since it
 * relies on the existence of this code.
 *
 * To complete the assignment, you will need to implement these
 * functions in the mail.cpp file.  I recommend that you implement
 * the functions in this order:
 *
 * 1. SaveAddressBook
 * 2. LoadAddressBook
 * 3. UserName (should be one line of code!)
 * 4. SendEmail
 */

#ifndef Mail_Included
#define Mail_Included

#include "EmailMessage.h"
#include <vector>
#include <string>
using namespace std;

/* Function: LoadAddressBook();
 * Usage: vector<string> addresses = LoadAddressBook();
 * ----------------------------------------------
 * Loads the user's address book from disk.  You can
 * store the address book however you see fit, but
 * this function should return it as a vector<string>.
 */
vector<string> LoadAddressBook();

/* Function: SaveAddressBook(vector<string>&);
 * Usage: SaveAddressBook(myAddresses);
 * ----------------------------------------------
 * Saves the specified set of addresses as the user's
 * address book.  You should overwrite any existing
 * addresses with the ones contained in this list.
 * Make sure that you save the data in the same format
 * that you load it!
 */
void SaveAddressBook(vector<string>& addressBook);

/* Function: UserName()
 * Usage: string myName = UserName();
 * ----------------------------------------------
 * Returns the email address that SendMail will use
 * in the "From:" field of each email.  This should be
 * your email address.
 */
string UserName();

/* Function: SendMessage(EmailMessage&);
 * Usage: SendMessage(myMessage);
 * ----------------------------------------------
 * Transmits an email message to smtp.stanford.edu
 * using SMTP.  The email will actually be sent to
 * the destination.  You will need to implement this
 * function yourself.
 */
bool SendEmail(EmailMessage& message);

#endif
